Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegexFromGlob ¶
RegexFromGlob converts the glob string into a regexp string with options "extended" & "glob-star" enabled, and with the default delimiter '/'
func RegexFromGlobWithOptions ¶
RegexFromGlobWithOptions converts glob to regexp string with the given options
Types ¶
Click to show internal directories.
Click to hide internal directories.